import 'package:flutter/material.dart';

enum AnimationType { normal, fadeIn }

class AnimatesTransition {
  final BuildContext context;
  final Widget child;
  final AnimationType? animation;
  final Duration duration;
  final bool replacement;

  AnimatesTransition({
    this.replacement = false,
    this.duration = const Duration(milliseconds: 300),
    required this.context,
    required this.child,
    this.animation = AnimationType.normal,
  }) {
    switch (this.animation) {
      case AnimationType.normal:
        this._normalTransition();
        break;
      case AnimationType.fadeIn:
        this._fadeInTransition();
        break;
      default:
        _normalTransition();
    }
  }

  void _normalTransition() {
    Navigator.push(this.context, MaterialPageRoute(builder: (_) => this.child));
  }

  void pushPageValidate(Route route) => replacement
      ? Navigator.pushReplacement(context, route)
      : Navigator.push(context, route);

  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (_, __, ___) => this.child,
        transitionDuration: this.duration,
        transitionsBuilder: (_, animation, __, child) {
          return FadeTransition(
            opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                CurvedAnimation(parent: animation, curve: Curves.easeOut)),
            child: child,
          );
        });
    pushPageValidate(route);
  }
}
